@@ -12,7 +12,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tcl.h,v 1.43.2.1 1999/05/19 23:27:09 redman Exp $
+ * RCS: @(#) $Id: tcl.h,v 1.57 1999/08/10 23:16:25 redman Exp $
  */
 
 #ifndef _TCL
@@ -40,6 +40,7 @@ extern "C" {
  *
  * library/init.tcl	(only if major.minor changes, not patchlevel)
  * unix/configure.in
+ * win/configure.in	(only if major.minor changes, not patchlevel)
  * win/makefile.bc	(only if major.minor changes, not patchlevel)
  * win/makefile.vc	(only if major.minor changes, not patchlevel)
  * win/pkgIndex.tcl	(for tclregNN.dll, not patchlevel)
@@ -48,15 +49,17 @@ extern "C" {
  * win/README.binary
  * win/README		(only if major.minor changes, not patchlevel)
  * unix/README		(only if major.minor changes, not patchlevel)
+ * tools/tcl.hpj.in	(for windows installer)
+ * tools/tcl.wse.in	(for windows installer)
  */
 
 #define TCL_MAJOR_VERSION   8
-#define TCL_MINOR_VERSION   1
+#define TCL_MINOR_VERSION   2
 #define TCL_RELEASE_LEVEL   TCL_FINAL_RELEASE
-#define TCL_RELEASE_SERIAL  1
+#define TCL_RELEASE_SERIAL  0
 
-#define TCL_VERSION	    "8.1"
-#define TCL_PATCH_LEVEL	    "8.1.1+"
+#define TCL_VERSION	    "8.2"
+#define TCL_PATCH_LEVEL	    "8.2.0+"
 
 /*
  * The following definitions set up the proper options for Windows
@@ -376,6 +379,63 @@ typedef struct Tcl_TimerToken_ *Tcl_TimerToken;
 typedef struct Tcl_Trace_ *Tcl_Trace;
 typedef struct Tcl_Var_ *Tcl_Var;
 
+/*
+ * Flag values passed to Tcl_GetRegExpFromObj.
+ */
+
+#define	TCL_REG_BASIC		000000	/* BREs (convenience) */
+#define	TCL_REG_EXTENDED	000001	/* EREs */
+#define	TCL_REG_ADVF		000002	/* advanced features in EREs */
+#define	TCL_REG_ADVANCED	000003	/* AREs (which are also EREs) */
+#define	TCL_REG_QUOTE		000004	/* no special characters, none */
+#define	TCL_REG_NOCASE		000010	/* ignore case */
+#define	TCL_REG_NOSUB		000020	/* don't care about subexpressions */
+#define	TCL_REG_EXPANDED	000040	/* expanded format, white space &
+					 * comments */
+#define	TCL_REG_NLSTOP		000100  /* \n doesn't match . or [^ ] */
+#define	TCL_REG_NLANCH		000200  /* ^ matches after \n, $ before */
+#define	TCL_REG_NEWLINE		000300  /* newlines are line terminators */
+#define	TCL_REG_CANMATCH	001000  /* report details on partial/limited
+					 * matches */
+
+/*
+ * The following flag is experimental and only intended for use by Expect.  It
+ * will probably go away in a later release.
+ */
+
+#define TCL_REG_BOSONLY		002000	/* prepend \A to pattern so it only
+					 * matches at the beginning of the
+					 * string. */
+
+/*
+ * Flags values passed to Tcl_RegExpExecObj.
+ */
+
+#define	TCL_REG_NOTBOL	0001	/* Beginning of string does not match ^.  */
+#define	TCL_REG_NOTEOL	0002	/* End of string does not match $. */
+
+/*
+ * Structures filled in by Tcl_RegExpInfo.  Note that all offset values are
+ * relative to the start of the match string, not the beginning of the
+ * entire string.
+ */
+
+typedef struct Tcl_RegExpIndices {
+    long start;		/* character offset of first character in match */
+    long end;		/* character offset of first character after the
+			 * match. */
+} Tcl_RegExpIndices;
+
+typedef struct Tcl_RegExpInfo {
+    int nsubs;			/* number of subexpressions in the
+				 * compiled expression */
+    Tcl_RegExpIndices *matches;	/* array of nsubs match offset
+				 * pairs */
+    long extendStart;		/* The offset at which a subsequent
+				 * match might begin. */
+    long reserved;		/* Reserved for later use. */
+} Tcl_RegExpInfo;
+
 /*
  * Picky compilers complain if this typdef doesn't appear before the
  * struct's reference in tclDecls.h.
@@ -521,6 +581,10 @@ typedef int (Tcl_SetFromAnyProc) _ANSI_ARGS_((Tcl_Interp *interp,
 typedef void (Tcl_UpdateStringProc) _ANSI_ARGS_((struct Tcl_Obj *objPtr));
 typedef char *(Tcl_VarTraceProc) _ANSI_ARGS_((ClientData clientData,
 	Tcl_Interp *interp, char *part1, char *part2, int flags));
+typedef void (Tcl_CreateFileHandlerProc) _ANSI_ARGS_((int fd, int mask,
+	Tcl_FileProc *proc, ClientData clientData));
+typedef void (Tcl_DeleteFileHandlerProc) _ANSI_ARGS_((int fd));
+typedef int (Tcl_MainLoopProc) _ANSI_ARGS_((void));
 
 /*
  * The following structure represents a type of object, which is a
@@ -594,9 +658,9 @@ typedef struct Tcl_Obj {
  * expression that is expensive to compute or has side effects.
  */
 
-EXTERN void		Tcl_IncrRefCount _ANSI_ARGS_((Tcl_Obj *objPtr));
-EXTERN void		Tcl_DecrRefCount _ANSI_ARGS_((Tcl_Obj *objPtr));
-EXTERN int		Tcl_IsShared _ANSI_ARGS_((Tcl_Obj *objPtr));
+void		Tcl_IncrRefCount _ANSI_ARGS_((Tcl_Obj *objPtr));
+void		Tcl_DecrRefCount _ANSI_ARGS_((Tcl_Obj *objPtr));
+int		Tcl_IsShared _ANSI_ARGS_((Tcl_Obj *objPtr));
 
 #ifdef TCL_MEM_DEBUG
 #   define Tcl_IncrRefCount(objPtr) \
@@ -1042,6 +1106,9 @@ typedef struct Tcl_Time {
     long usec;			/* Microseconds. */
 } Tcl_Time;
 
+typedef void (Tcl_SetTimerProc) _ANSI_ARGS_((Tcl_Time *timePtr));
+typedef int (Tcl_WaitForEventProc) _ANSI_ARGS_((Tcl_Time *timePtr));
+
 /*
  * Bits to pass to Tcl_CreateFileHandler and Tcl_CreateChannelHandler
  * to indicate what sorts of events are of interest:
@@ -1126,22 +1193,15 @@ typedef int	(Tcl_DriverGetHandleProc) _ANSI_ARGS_((
 #else /* !TCL_MEM_DEBUG */
 
 /*
- * If USE_TCLALLOC is true, then we need to call Tcl_Alloc instead of
- * the native malloc/free.  The only time USE_TCLALLOC should not be
- * true is when compiling the Tcl/Tk libraries on Unix systems.  In this
- * case we can safely call the native malloc/free directly as a performance
- * optimization.
+ * If we are not using the debugging allocator, we should call the 
+ * Tcl_Alloc, et al. routines in order to guarantee that every module
+ * is using the same memory allocator both inside and outside of the
+ * Tcl library.
  */
 
-#   if USE_TCLALLOC
-#	define ckalloc(x) Tcl_Alloc(x)
-#	define ckfree(x) Tcl_Free(x)
-#	define ckrealloc(x,y) Tcl_Realloc(x,y)
-#   else
-#	define ckalloc(x) malloc(x)
-#	define ckfree(x)  free(x)
-#	define ckrealloc(x,y) realloc(x,y)
-#   endif
+#   define ckalloc(x) Tcl_Alloc(x)
+#   define ckfree(x) Tcl_Free(x)
+#   define ckrealloc(x,y) Tcl_Realloc(x,y)
 #   define Tcl_InitMemory(x)
 #   define Tcl_DumpActiveMemory(x)
 #   define Tcl_ValidateAllMemory(x,y)
@@ -1228,6 +1288,18 @@ typedef enum Tcl_PathType {
     TCL_PATH_VOLUME_RELATIVE
 } Tcl_PathType;
 
+/*
+ * The following structure represents the Notifier functions that
+ * you can override with the Tcl_SetNotifier call.
+ */
+
+typedef struct Tcl_NotifierProcs {
+    Tcl_SetTimerProc *setTimerProc;
+    Tcl_WaitForEventProc *waitForEventProc;
+    Tcl_CreateFileHandlerProc *createFileHandlerProc;
+    Tcl_DeleteFileHandlerProc *deleteFileHandlerProc;
+} Tcl_NotifierProcs;
+
 /*
  * The following structure represents a user-defined encoding.  It collects
  * together all the functions that are used by the specific encoding.
@@ -1551,6 +1623,8 @@ typedef unsigned short Tcl_UniChar;
 #define Tcl_TildeSubst Tcl_TranslateFileName
 #define panic Tcl_Panic
 #define panicVA Tcl_PanicVA
+#define Tcl_ReplaceChannel	Tcl_StackChannel
+#define Tcl_UndoReplaceChannel	Tcl_UnstackChannel
 
 /*
  * The following constant is used to test for older versions of Tcl
