@@ -5,12 +5,12 @@
  *	in systems that don't support dynamic loading; it just returns
  *	an error.
  *
- * Copyright (c) 1995-1996 Sun Microsystems, Inc.
+ * Copyright (c) 1995-1997 Sun Microsystems, Inc.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclLoadNone.c,v 1.2 1998/09/14 18:40:00 stanton Exp $
+ * RCS: @(#) $Id: tclLoadNone.c,v 1.4 1999/05/07 20:07:40 stanton Exp $
  */
 
 #include "tclInt.h"
@@ -36,6 +36,7 @@
  *
  *----------------------------------------------------------------------
  */
+
 VOID *dlopen(path, mode)
     CONST char *path;
     int mode;
@@ -53,9 +54,9 @@ VOID *dlsym(handle, symbol)
 char *dlerror() {
     return "dynamic loading is not currently available on this system";
 }
-
-int dlclose(handle)
-    VOID *handle;
-{
-    return -1;
-}
+  
+! int dlclose(handle)
+!     VOID *handle;
+  {
+!     return -1;
+  }
