@@ -10,13 +10,10 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: pkge.c,v 1.2 1998/09/14 18:40:18 stanton Exp $
+ * RCS: @(#) $Id: pkge.c,v 1.4 1999/04/16 00:48:06 stanton Exp $
  */
-#include "tcl.h"
 
-#ifndef TCL_USE_STUBS
-#define Tcl_Required(a,b,c) Tcl_PkgRequire(a,"Tcl",b,c)
-#endif
+#include "tcl.h"
 
 
 /*
@@ -37,25 +34,13 @@
  */
 
 int
-#ifdef _USING_PROTOTYPES_
-Pkge_Init (
-    Tcl_Interp *interp)		/* Interpreter in which the package is
-				 * to be made available. */
-#else
 Pkge_Init(interp)
     Tcl_Interp *interp;		/* Interpreter in which the package is
 				 * to be made available. */
-#endif
 {
-    int result;
     static char script[] = "if 44 {open non_existent}";
-
-    if (Tcl_Required(interp, "8", 0) == NULL) {
+    if (Tcl_InitStubs(interp, TCL_VERSION, 1) == NULL) {
 	return TCL_ERROR;
     }
-    if (Tcl_PkgProvide(interp, "Pkge", "1.7") != TCL_OK) {
-	return TCL_ERROR;
-    }
-
     return Tcl_Eval(interp, script);
 }
