@@ -3,43 +3,18 @@
  *
  *	Contains platform specific test commands for the Unix platform.
  *
- * Copyright (c) 1996 Sun Microsystems, Inc.
+ * Copyright (c) 1996-1997 Sun Microsystems, Inc.
  * Copyright (c) 1998 by Scriptics Corporation.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclUnixTest.c,v 1.9 1998/10/14 00:32:55 rjohnson Exp $
+ * RCS: @(#) $Id: tclUnixTest.c,v 1.10 1999/04/16 00:48:05 stanton Exp $
  */
 
 #include "tclInt.h"
 #include "tclPort.h"
 
-/*
- * If using stub macro's, make sure that 4 internal definitions
- * are available. They are not defined in tcl.h or tclInt.h,
- * because they are not meant to be used anywhere else than
- * in this test.
- */
-
-#ifdef TCL_USE_STUBS
-
-Tcl_StubTable *tclStubTable;
-#define TclpCloseFile(file) \
-	(tclStubTable->closeFile(file))
-#define TclpCreatePipe(readPipe, writePipe) \
-	(tclStubTable->createPipe((VOID *) (readPipe), (VOID *) (writePipe)))
-#define TclUnixWaitForFile(fd, mask, timeout) \
-	(tclStubTable->unixWaitForFile(fd, mask, timeout))
-#define tclExecutableName \
-	(*(tclStubTable->executableName))
-
-#else /* TCL_USE_STUBS */
-
-#define Tcl_Required(a,b,c) Tcl_PkgRequire(a,"Tcl",b,c)
-
-#endif /* TCL_USE_STUBS */
-
 /*
  * The headers are needed for the testalarm command that verifies the
  * use of SA_RESTART in signal handlers.
@@ -102,8 +77,12 @@ static int		TestfindexecutableCmd _ANSI_ARGS_((ClientData dummy,
 			    Tcl_Interp *interp, int argc, char **argv));
 static int		TestgetopenfileCmd _ANSI_ARGS_((ClientData dummy,
 			    Tcl_Interp *interp, int argc, char **argv));
+static int		TestgetdefencdirCmd _ANSI_ARGS_((ClientData dummy,
+			    Tcl_Interp *interp, int argc, char **argv));
+static int		TestsetdefencdirCmd _ANSI_ARGS_((ClientData dummy,
+			    Tcl_Interp *interp, int argc, char **argv));
 int			TclplatformtestInit _ANSI_ARGS_((Tcl_Interp *interp));
-int			Unixtest_Init _ANSI_ARGS_((Tcl_Interp *interp));
+int			Tclptest_Init _ANSI_ARGS_((Tcl_Interp *interp));
 static int		TestalarmCmd _ANSI_ARGS_((ClientData dummy,
 			    Tcl_Interp *interp, int argc, char **argv));
 static int		TestgotsigCmd _ANSI_ARGS_((ClientData dummy,
@@ -136,13 +115,13 @@ TclplatformtestInit(interp)
     Tcl_Interp *interp;		/* Interpreter to add commands to. */
 #endif
 {
-    return Unixtest_Init(interp);
+    return Tclptest_Init(interp);
 }
 
 /*
  *----------------------------------------------------------------------
  *
- * Unixtest_Init --
+ * Tclptest_Init --
  *
  *	Defines commands that test platform specific functionality for
  *	Unix platforms.
@@ -158,26 +137,17 @@ TclplatformtestInit(interp)
 
 int
 #ifdef _USING_PROTOTYPES_
-Unixtest_Init (
+Tclptest_Init (
     Tcl_Interp *interp)		/* Interpreter to add commands to. */
 #else
-Unixtest_Init(interp)
+Tclptest_Init(interp)
     Tcl_Interp *interp;		/* Interpreter to add commands to. */
 #endif
 {
-    if (Tcl_Required(interp, TCL_VERSION, 1) == NULL) {
+    if (Tcl_InitStubs(interp, TCL_VERSION, 1) == NULL) {
 	return TCL_ERROR;
     }
-#ifdef TCL_USE_STUBS
-    if (tclStubTable->magic != TCL_STUB_MAGIC ||
-	    tclStubTable->magic2 != TCL_STUB_MAGIC) {
-	Tcl_AppendResult(interp, "Cannot execute test: ",
-		"Incompatible stub table in Tcl\n",
-		"Please recompile the UNIX test function", 0);
-	return TCL_ERROR;
-    }
-#endif
-    if (Tcl_PkgProvide(interp, "Unixtest", TCL_VERSION) != TCL_OK) {
+    if (Tcl_PkgProvide(interp, "Tclptest", TCL_VERSION) != TCL_OK) {
         return TCL_ERROR;
     }
     Tcl_CreateCommand(interp, "testfilehandler", TestfilehandlerCmd,
@@ -188,6 +158,10 @@ Unixtest_Init(interp)
             (ClientData) 0, (Tcl_CmdDeleteProc *) NULL);
     Tcl_CreateCommand(interp, "testgetopenfile", TestgetopenfileCmd,
             (ClientData) 0, (Tcl_CmdDeleteProc *) NULL);
+    Tcl_CreateCommand(interp, "testgetdefenc", TestgetdefencdirCmd,
+            (ClientData) 0, (Tcl_CmdDeleteProc *) NULL);
+    Tcl_CreateCommand(interp, "testsetdefenc", TestsetdefencdirCmd,
+            (ClientData) 0, (Tcl_CmdDeleteProc *) NULL);
     Tcl_CreateCommand(interp, "testalarm", TestalarmCmd,
             (ClientData) 0, (Tcl_CmdDeleteProc *) NULL);
     Tcl_CreateCommand(interp, "testgotsig", TestgotsigCmd,
@@ -280,7 +254,7 @@ TestfilehandlerCmd(dummy, interp, argc, argv)
 	}
 	pipePtr->readCount = pipePtr->writeCount = 0;
     } else if (strcmp(argv[1], "counts") == 0) {
-	char buf[30];
+	char buf[TCL_INTEGER_SPACE * 2];
 	
 	if (argc != 3) {
 	    Tcl_AppendResult(interp, "wrong # arguments: should be \"",
@@ -362,7 +336,7 @@ TestfilehandlerCmd(dummy, interp, argc, argv)
             /* Empty loop body. */
         }
     } else if (strcmp(argv[1], "fillpartial") == 0) {
-	char buf[30];
+	char buf[TCL_INTEGER_SPACE];
 	
 	if (argc != 3) {
 	    Tcl_AppendResult(interp, "wrong # arguments: should be \"",
@@ -371,7 +345,7 @@ TestfilehandlerCmd(dummy, interp, argc, argv)
 	}
 
 	memset((VOID *) buffer, 'b', 10);
-	sprintf(buf, "%d", write(GetFd(pipePtr->writeFile), buffer, 10));
+	TclFormatInt(buf, write(GetFd(pipePtr->writeFile), buffer, 10));
 	Tcl_SetResult(interp, buf, TCL_VOLATILE);
     } else if (strcmp(argv[1], "oneevent") == 0) {
 	Tcl_DoOneEvent(TCL_FILE_EVENTS|TCL_DONT_WAIT);
@@ -549,20 +523,29 @@ TestfindexecutableCmd(clientData, interp, argc, argv)
 #endif
 {
     char *oldName;
+    char *oldNativeName;
 
     if (argc != 2) {
 	Tcl_AppendResult(interp, "wrong # arguments: should be \"", argv[0],
 		" argv0\"", (char *) NULL);
 	return TCL_ERROR;
     }
-    oldName = tclExecutableName;
-    tclExecutableName = NULL;
+
+    oldName       = tclExecutableName;
+    oldNativeName = tclNativeExecutableName;
+
+    tclExecutableName       = NULL;
+    tclNativeExecutableName = NULL;
+
     Tcl_FindExecutable(argv[1]);
     if (tclExecutableName != NULL) {
 	Tcl_SetResult(interp, tclExecutableName, TCL_VOLATILE);
 	ckfree(tclExecutableName);
     }
-    tclExecutableName = oldName;
+
+    tclExecutableName       = oldName;
+    tclNativeExecutableName = oldNativeName;
+
     return TCL_OK;
 }
 
@@ -619,6 +602,87 @@ TestgetopenfileCmd(dummy, interp, argc, argv)
     return TCL_OK;
 }
 
+/*
+ *----------------------------------------------------------------------
+ *
+ * TestsetdefencdirCmd --
+ *
+ *	This procedure implements the "testsetdefenc" command. It is
+ *	used to set the value of tclDefaultEncodingDir.
+ *
+ * Results:
+ *	A standard Tcl result.
+ *
+ * Side effects:
+ *	None.
+ *
+ *----------------------------------------------------------------------
+ */
+
+static int
+TestsetdefencdirCmd(clientData, interp, argc, argv)
+    ClientData clientData;		/* Not used. */
+    Tcl_Interp *interp;			/* Current interpreter. */
+    int argc;				/* Number of arguments. */
+    char **argv;			/* Argument strings. */
+{
+    if (argc != 2) {
+        Tcl_AppendResult(interp,
+                "wrong # args: should be \"", argv[0],
+                " defaultDir\"",
+                (char *) NULL);
+        return TCL_ERROR;
+    }
+
+    if (tclDefaultEncodingDir != NULL) {
+	ckfree(tclDefaultEncodingDir);
+	tclDefaultEncodingDir = NULL;
+    }
+    if (*argv[1] != '\0') {
+	tclDefaultEncodingDir = (char *)
+	    ckalloc((unsigned) strlen(argv[1]) + 1);
+	strcpy(tclDefaultEncodingDir, argv[1]);
+    }
+    return TCL_OK;
+}
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * TestgetdefencdirCmd --
+ *
+ *	This procedure implements the "testgetdefenc" command. It is
+ *	used to get the value of tclDefaultEncodingDir.
+ *
+ * Results:
+ *	A standard Tcl result.
+ *
+ * Side effects:
+ *	None.
+ *
+ *----------------------------------------------------------------------
+ */
+
+static int
+TestgetdefencdirCmd(clientData, interp, argc, argv)
+    ClientData clientData;		/* Not used. */
+    Tcl_Interp *interp;			/* Current interpreter. */
+    int argc;				/* Number of arguments. */
+    char **argv;			/* Argument strings. */
+{
+    if (argc != 1) {
+        Tcl_AppendResult(interp,
+                "wrong # args: should be \"", argv[0],
+                (char *) NULL);
+        return TCL_ERROR;
+    }
+
+    if (tclDefaultEncodingDir != NULL) {
+        Tcl_AppendResult(interp, tclDefaultEncodingDir, (char *) NULL);
+    }
+    return TCL_OK;
+}
+
 /*
  *----------------------------------------------------------------------
  * TestalarmCmd --
